==> client-sdk-react-1.0.0.tgz: package/src/components/Chat/SplitChat.tsx <==
import React, { useEffect, useRef } from 'react'
import { selectRemoteParticipants } from '../../store'
import { useZocksStore } from '../../app'
import { ChatInputElementProps, ChatProps, RecipientSelectorElementProps } from './models'
import { useChat } from './hooks'
import { CustomizableChatInput, RecipientSelector } from './ChatInput'
import { ChatMessageWithAvatar } from './ChatMessage'
import { setMessageRecipient } from '../../store/chat/chatSlice'
import { useZocksDispatch } from '../../app/hooks'
import './Chat.scss'

interface SplitChatProps extends ChatProps {
  recipientSelectorElement?: React.FC<RecipientSelectorElementProps> | null
}

export const SplitChat: React.FC<SplitChatProps> = ({
  chatActions,
  dismiss,
  onNewChatMessage,
  chatMessageElement = null,
  chatInputElement = null,
  recipientSelectorElement = null,
}) => {
  const dispatch = useZocksDispatch()
  const {
    sendPublicMessage,
    sendPrivateMessage,
    uploadAttachment,
    getAttachmentLocation,
    publicChatMessages,
    privateChatMessages,
    messageRecipient,
  } = useChat(chatActions)
  const remoteParticipants = useZocksStore(selectRemoteParticipants)

  const messagesEndRef = useRef<HTMLDivElement>(null)
  const scrollToBottom = () => {
    messagesEndRef.current?.scrollIntoView({ behavior: 'smooth' })
  }

  useEffect(() => {
    scrollToBottom()
  }, [publicChatMessages, privateChatMessages])

  useEffect(() => {
    if (publicChatMessages.length) {
      onNewChatMessage && onNewChatMessage()
    }
  }, [publicChatMessages.length, onNewChatMessage])

  useEffect(() => {
    if (Object.keys(privateChatMessages).length) {
      onNewChatMessage && onNewChatMessage()
    }
  }, [privateChatMessages, onNewChatMessage])

  const ChatMessageElement = chatMessageElement ?? ChatMessageWithAvatar
  const ChatInputElement = chatInputElement ?? ChatInputWithoutRecipientSelector
  const RecipientSelectorElement = recipientSelectorElement ?? RecipientSelector

  const handleRecipientSelected = (recipientId: string) => {
    dispatch(setMessageRecipient(recipientId))
  }

  const selectedRecipientMessages = !messageRecipient ? publicChatMessages : privateChatMessages[messageRecipient] || []

  return (
    <div className='chat'>
      {dismiss && (
        <div className='chat__header'>
          <button onClick={dismiss} aria-label='Dismiss' />
        </div>
      )}
      <div className='chat__main-container'>
        <RecipientSelectorElement
          onRecipientSelected={handleRecipientSelected}
          remoteParticipants={remoteParticipants}
        />
        <div className='chat__messages-container'>
          <div className='chat__messages-scroll'>
            {selectedRecipientMessages.map((chatMessage, idx) => {
              const lastMessageByParticipant = selectedRecipientMessages
                .map((m) => m.from.id === chatMessage.from.id)
                .lastIndexOf(true)
              return (
                <ChatMessageElement
                  key={idx}
                  chatMessage={chatMessage}
                  showAvatar={idx === lastMessageByParticipant}
                  getAttachmentLocation={getAttachmentLocation}
                />
              )
            })}
            <div ref={messagesEndRef} />
          </div>
        </div>
        <div className='chat__footer'>
          <ChatInputElement
            messageRecipient={messageRecipient}
            remoteParticipants={remoteParticipants}
            sendPublicMessage={sendPublicMessage}
            sendPrivateMessage={sendPrivateMessage}
            uploadAttachment={uploadAttachment}
          />
        </div>
      </div>
    </div>
  )
}

const ChatInputWithoutRecipientSelector: React.FC<ChatInputElementProps> = (props) => {
  return <CustomizableChatInput {...props} recipientSelectorElement={() => null} />
}

==> client-sdk-react-1.1.2.tgz: package/src/components/Chat/SplitChat.tsx <==
import React, { useEffect, useRef } from 'react'
import { useChat, selectRemoteParticipants } from '../../store'
import { useZocksStore } from '../../app'
import { ChatInputElementProps, ChatProps, RecipientSelectorElementProps } from './models'
import { CustomizableChatInput, RecipientSelector } from './ChatInput'
import { ChatMessageWithAvatar } from './ChatMessage'
import { setMessageRecipient } from '../../store/chat/chatSlice'
import { useZocksDispatch } from '../../app/hooks'
import './Chat.scss'

interface SplitChatProps extends ChatProps {
  recipientSelectorElement?: React.FC<RecipientSelectorElementProps>
}

export const SplitChat: React.FC<SplitChatProps> = ({
  chatActions,
  dismiss,
  chatMessageElement,
  chatInputElement,
  recipientSelectorElement,
}) => {
  const dispatch = useZocksDispatch()
  const {
    sendPublicMessage,
    sendPrivateMessage,
    uploadAttachment,
    getAttachmentLocation,
    publicChatMessages,
    privateChatMessages,
    messageRecipient,
  } = useChat(chatActions)
  const remoteParticipants = useZocksStore(selectRemoteParticipants)

  const messagesEndRef = useRef<HTMLDivElement>(null)
  const scrollToBottom = () => {
    messagesEndRef.current?.scrollIntoView({ behavior: 'smooth' })
  }

  useEffect(() => {
    scrollToBottom()
  }, [publicChatMessages, privateChatMessages])

  const ChatMessageElement = chatMessageElement ?? ChatMessageWithAvatar
  const ChatInputElement = chatInputElement ?? ChatInputWithoutRecipientSelector
  const RecipientSelectorElement = recipientSelectorElement ?? RecipientSelector

  const handleRecipientSelected = (recipientId: string) => {
    dispatch(setMessageRecipient(recipientId))
  }

  const selectedRecipientMessages = !messageRecipient ? publicChatMessages : privateChatMessages[messageRecipient] || []

  return (
    <div className='chat'>
      {dismiss && (
        <div className='chat__header'>
          <button onClick={dismiss} aria-label='Dismiss' />
        </div>
      )}
      <div className='chat__main-container'>
        <RecipientSelectorElement
          onRecipientSelected={handleRecipientSelected}
          remoteParticipants={remoteParticipants}
        />
        <div className='chat__messages-container'>
          <div className='chat__messages-scroll'>
            {selectedRecipientMessages.map((chatMessage, idx) => {
              const lastMessageByParticipant = selectedRecipientMessages
                .map((m) => m.from.id === chatMessage.from.id)
                .lastIndexOf(true)
              return (
                <ChatMessageElement
                  key={idx}
                  chatMessage={chatMessage}
                  showAvatar={idx === lastMessageByParticipant}
                  getAttachmentLocation={getAttachmentLocation}
                />
              )
            })}
            <div ref={messagesEndRef} />
          </div>
        </div>
        <div className='chat__footer'>
          <ChatInputElement
            messageRecipient={messageRecipient}
            remoteParticipants={remoteParticipants}
            sendPublicMessage={sendPublicMessage}
            sendPrivateMessage={sendPrivateMessage}
            uploadAttachment={uploadAttachment}
          />
        </div>
      </div>
    </div>
  )
}

const ChatInputWithoutRecipientSelector: React.FC<ChatInputElementProps> = (props) => {
  return <CustomizableChatInput {...props} recipientSelectorElement={() => null} />
}
